package com.ruoyi.ss.riskInfo.service.impl;

import java.time.LocalDateTime;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.ss.riskInfo.domain.enums.RiskInfoStatus;
import com.ruoyi.ss.riskInfo.service.RiskInfoValidator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ss.riskInfo.mapper.RiskInfoMapper;
import com.ruoyi.ss.riskInfo.domain.RiskInfo;
import com.ruoyi.ss.riskInfo.domain.RiskInfoVO;
import com.ruoyi.ss.riskInfo.domain.RiskInfoQuery;
import com.ruoyi.ss.riskInfo.service.RiskInfoService;

/**
 * 风控材料Service业务层处理
 *
 * @author ruoyi
 * @date 2024-11-25
 */
@Service
public class RiskInfoServiceImpl implements RiskInfoService
{
    @Autowired
    private RiskInfoMapper riskInfoMapper;

    @Autowired
    private RiskInfoValidator riskInfoValidator;

    /**
     * 查询风控材料
     *
     * @param infoId 风控材料主键
     * @return 风控材料
     */
    @Override
    public RiskInfoVO selectRiskInfoByInfoId(Long infoId)
    {
        return riskInfoMapper.selectRiskInfoByInfoId(infoId);
    }

    /**
     * 查询风控材料列表
     *
     * @param riskInfo 风控材料
     * @return 风控材料
     */
    @Override
    public List<RiskInfoVO> selectRiskInfoList(RiskInfoQuery riskInfo)
    {
        return riskInfoMapper.selectRiskInfoList(riskInfo);
    }

    /**
     * 新增风控材料
     *
     * @param riskInfo 风控材料
     * @return 结果
     */
    @Override
    public int insertRiskInfo(RiskInfo riskInfo) {
        // 校验
        riskInfoValidator.preCheck(riskInfo);
        riskInfo.setCreateTime(DateUtils.getNowDate());
        return riskInfoMapper.insertRiskInfo(riskInfo);
    }

    /**
     * 修改风控材料
     *
     * @param riskInfo 风控材料
     * @return 结果
     */
    @Override
    public int updateRiskInfo(RiskInfo riskInfo) {
        // 校验
        riskInfoValidator.preCheck(riskInfo);
        return riskInfoMapper.updateRiskInfo(riskInfo);
    }

    /**
     * 批量删除风控材料
     *
     * @param infoIds 需要删除的风控材料主键
     * @return 结果
     */
    @Override
    public int deleteRiskInfoByInfoIds(Long[] infoIds)
    {
        return riskInfoMapper.deleteRiskInfoByInfoIds(infoIds);
    }

    /**
     * 删除风控材料信息
     *
     * @param infoId 风控材料主键
     * @return 结果
     */
    @Override
    public int deleteRiskInfoByInfoId(Long infoId)
    {
        return riskInfoMapper.deleteRiskInfoByInfoId(infoId);
    }

    @Override
    public int submit(Long infoId) {
        if (infoId == null) {
            return 0;
        }

        // 校验数据
        RiskInfoVO info = this.selectRiskInfoByInfoId(infoId);
        riskInfoValidator.preSubmitCheck(info);

        RiskInfoVO data = new RiskInfoVO();
        data.setInfoId(infoId);
        data.setSubmitTime(LocalDateTime.now());
        data.setStatus(RiskInfoStatus.WAIT_VERIFY.getStatus());
        return riskInfoMapper.updateRiskInfo(data);
    }

    @Override
    public int updateRealName(Long infoId, Long realNameId) {
        if (infoId == null || realNameId == null) {
            return 0;
        }
        RiskInfo data = new RiskInfo();
        data.setInfoId(infoId);
        data.setRealNameId(realNameId);
        return this.updateRiskInfo(data);
    }
}
